PyXMake Developer Guide: PyXMake.VTL.api Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.api Namespace Reference

## Functions
| main (handle, Hostname=str(platform.node()), PortID=8020, **kwargs)
| handle ()

## Detailed Description

    API setup example for PyXMake.

    @note: Run HTML APIs of PyXMake (in a Docker container or locally).
    Created on 28.02.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                                                          [DLR-SY,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ handle()

PyXMake.VTL.api.handle | ( |  | ) |

    Return current API's main instance as an sub API.

Definition at line 70 of file api.py.

## ◆ main()

PyXMake.VTL.api.main | ( |  | handle,
|  |  | Hostname = str(platform.node()),
|  |  | PortID = 8020,
|  | ** | kwargs )

    Main function to execute an API handle

Definition at line 35 of file api.py.